# -*- coding: utf-8 -*-
from django import forms
from django.core.mail import EmailMessage
from django.template.loader import render_to_string
from django.utils.translation import ugettext_lazy as _
from django.core.mail import EmailMultiAlternatives
from django.template.loader import get_template
from django.template import Context

class ContactForm(forms.Form):
    SET_POSIZIONE = (
        ("", "---"),
        ("progettista", _("Designer")),
        ("produzione", _("Production Manager")),
        ("commerciale", _("Commercial/Sales")),
        ("tecnico", _("Technical")),
        ("acquisti", _("Purchasing Manager")),
        ("altro", _("Other")),
    )
    SET_AREA = (
        ("", "---"),
        ("direzione", _("Direction")),
        ("vendite", _("Sell")),
        ("marketing", _("Marketing")),
        ("amministrazione", _("Administration")),
        ("ufficiotecnico", _("Technical Office")),
        ("logistica", _("Logistics and Shipping")),
        ("informazioni", _("General Information")),
    )
    nome = forms.CharField(label=_("First Name"))
    cognome = forms.CharField(label=_("Last Name"))
    azienda = forms.CharField(label=_("Company"))
    settore = forms.CharField(label=_("Field"), required=False)
    posizione = forms.ChoiceField(label=_("Position"), choices=SET_POSIZIONE)
    indirizzo = forms.CharField(label=_("Complete Address"), required=False)
    email = forms.EmailField()
    telefono = forms.CharField(label=_("Phone"), required=False)
    area = forms.ChoiceField(label=_("Area to which send the message"), choices=SET_AREA)
    privacy = forms.BooleanField(label=_("Privacy Statement"))
    messaggio = forms.CharField(label=_("Message"), required=True, widget=forms.Textarea(attrs={'placeholder': _("Type your message here"), 'cols':'80'}))


    def send(self, instance):

        html_template = get_template('cms_plugins/contact_email.html')
        subject, from_email, to = 'Richiesta informazioni', 'email@example.org', instance.site_email
        d = Context({
                       'nome': self.cleaned_data["nome"], 'cognome': self.cleaned_data["cognome"], 'azienda': self.cleaned_data["azienda"], 'settore': self.cleaned_data["settore"],
                       'posizione': self.cleaned_data["posizione"], 'indirizzo': self.cleaned_data["indirizzo"], 'email': self.cleaned_data["email"], 'telefono':self.cleaned_data["telefono"],
                       'area': self.cleaned_data["area"], 'messaggio': self.cleaned_data["messaggio"]
                    })
        html_content = html_template.render(d)
        msg = EmailMultiAlternatives(subject, html_content, from_email, [to])
        msg.content_subtype = "html"
        msg.send()
